@@ -11,16 +11,16 @@ class Arg:
         self.alias = alias
         self.default = default
 
-    def getValue(self, value):
-        return value if value else self.default
+    def getValue(self, func, value):
+        return func(value) if value is not None else self.default
 
     def context(self, func, value):
-        value = self.getValue(value)
+        value = self.getValue(func, value)
         return {
-            self.key: func(value),
-            self.alias: func(value)
+            self.key: value,
+            self.alias: value
         } if self.alias else {
-            self.key: func(value)
+            self.key: value
         }
 
 
@@ -33,7 +33,7 @@ class String(Arg):
         return self.context(str, value)
 
 
-class Json:
+class Json(Arg):
 
     def load(self, value):
         return self.context(json.loads, value)
@@ -41,7 +41,8 @@ class Json:
     def dump(self, value):
         return self.context(json.dumps, value)
 
-class Int:
+
+class Int(Arg):
 
     def load(self, value):
         return self.context(int, value)
@@ -50,7 +51,7 @@ class Int:
         return self.context(int, value)
 
 
-class Float:
+class Float(Arg):
 
     def load(self, value):
         return self.context(float, value)
